@@ -15,26 +15,25 @@ import warnings
 from openstack.cloud import _utils
 from openstack.cloud import openstackcloud
 from openstack import exceptions
+from openstack import resource
 from openstack import warnings as os_warnings
 
 
 class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
-
-    # TODO(stephenfin): Remove 'cache' in a future major version
-    def list_volumes(self, cache=True):
+    def list_volumes(self, cache=None):
         """List all available volumes.
 
         :param cache: **DEPRECATED** This parameter no longer does anything.
         :returns: A list of volume ``Volume`` objects.
         """
-        warnings.warn(
-            "the 'cache' argument is deprecated and no longer does anything; "
-            "consider removing it from calls",
-            os_warnings.OpenStackDeprecationWarning,
-        )
+        if cache is not None:
+            warnings.warn(
+                "the 'cache' argument is deprecated and no longer does "
+                "anything; consider removing it from calls",
+                os_warnings.RemovedInSDK50Warning,
+            )
         return list(self.block_storage.volumes())
 
-    # TODO(stephenfin): Remove 'get_extra' in a future major version
     def list_volume_types(self, get_extra=None):
         """List all available volume types.
 
@@ -46,7 +45,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             warnings.warn(
                 "the 'get_extra' argument is deprecated and no longer does "
                 "anything; consider removing it from calls",
-                os_warnings.OpenStackDeprecationWarning,
+                os_warnings.RemovedInSDK50Warning,
             )
         return list(self.block_storage.types())
 
@@ -59,12 +58,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -94,12 +88,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -142,13 +131,18 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             wait = True
 
         if image:
-            image_obj = self.image.find_image(image)
-            if not image_obj:
-                raise exceptions.SDKException(
-                    f"Image {image} was requested as the basis for a new "
-                    f"volume but was not found on the cloud"
-                )
-            kwargs['imageRef'] = image_obj['id']
+            if isinstance(image, dict):
+                if not isinstance(image, resource.Resource):
+                    warnings.warn(
+                        "Support for passing image as a raw dict has "
+                        "been deprecated for removal. Consider passing a "
+                        "string name or ID or an Image object instead.",
+                        os_warnings.RemovedInSDK60Warning,
+                    )
+                kwargs['imageRef'] = image['id']
+            else:  # object
+                image_obj = self.image.find_image(image, ignore_missing=False)
+                kwargs['imageRef'] = image_obj['id']
         kwargs = self._get_volume_kwargs(kwargs)
         kwargs['size'] = size
 
@@ -227,8 +221,9 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
         :raises: :class:`~openstack.exceptions.SDKException` on operation
             error.
         """
-        volume = self.block_storage.find_volume(name_or_id)
-
+        volume = self.block_storage.find_volume(
+            name_or_id, ignore_missing=True
+        )
         if not volume:
             self.log.debug(
                 "Volume %(name_or_id)s does not exist",
@@ -247,14 +242,22 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
 
         return True
 
-    # TODO(stephenfin): Remove 'cache' in a future major version
-    def get_volumes(self, server, cache=True):
+    def get_volumes(self, server, cache=None):
         """Get volumes for a server.
 
         :param server: The server to fetch volumes for.
         :param cache: **DEPRECATED** This parameter no longer does anything.
         :returns: A list of volume ``Volume`` objects.
         """
+        if cache is not None:
+            warnings.warn(
+                "the 'cache' argument is deprecated and no longer does "
+                "anything; consider removing it from calls",
+                os_warnings.RemovedInSDK50Warning,
+            )
+            # avoid spamming warnings
+            cache = None
+
         volumes = []
         for volume in self.list_volumes(cache=cache):
             for attach in volume['attachments']:
@@ -271,9 +274,9 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
         """
         params = {}
         if name_or_id:
-            project = self.identity.find_project(name_or_id)
-            if not project:
-                raise exceptions.SDKException("project does not exist")
+            project = self.identity.find_project(
+                name_or_id, ignore_missing=False
+            )
             params['project'] = project
         return self.block_storage.get_limits(**params)
 
@@ -467,12 +470,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -542,12 +540,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -570,7 +563,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
                 {
                     'name': 'my-volume-snapshot',
                     'volume_id': 'e126044c-7b4c-43be-a32a-c9cbbc9ddb56',
-                    'all_tenants': 1
+                    'all_tenants': 1,
                 }
 
         :returns: A list of volume ``Snapshot`` objects.
@@ -590,7 +583,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
                     'name': 'my-volume-backup',
                     'status': 'available',
                     'volume_id': 'e126044c-7b4c-43be-a32a-c9cbbc9ddb56',
-                    'all_tenants': 1
+                    'all_tenants': 1,
                 }
 
         :returns: A list of volume ``Backup`` objects.
@@ -671,12 +664,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -698,12 +686,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -725,12 +708,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -744,7 +722,6 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
         volume_backups = self.list_volume_backups()
         return _utils._filter_list(volume_backups, name_or_id, filters)
 
-    # TODO(stephenfin): Remove 'get_extra' in a future major version
     def search_volume_types(
         self,
         name_or_id=None,
@@ -758,12 +735,7 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -774,7 +746,13 @@ class BlockStorageCloudMixin(openstackcloud._OpenStackCloudMixin):
 
         :returns: A list of volume ``Type`` objects, if any are found.
         """
-        volume_types = self.list_volume_types(get_extra=get_extra)
+        if get_extra is not None:
+            warnings.warn(
+                "the 'get_extra' argument is deprecated and no longer does "
+                "anything; consider removing it from calls",
+                os_warnings.RemovedInSDK50Warning,
+            )
+        volume_types = self.list_volume_types()
         return _utils._filter_list(volume_types, name_or_id, filters)
 
     def get_volume_type_access(self, name_or_id):
