@@ -14,6 +14,7 @@ import base64
 import functools
 import operator
 import time
+import warnings
 
 import iso8601
 
@@ -23,7 +24,9 @@ from openstack.cloud import exc
 from openstack.cloud import meta
 from openstack.compute.v2 import server as _server
 from openstack import exceptions
+from openstack import resource
 from openstack import utils
+from openstack import warnings as os_warnings
 
 
 _SERVER_FIELDS = (
@@ -69,7 +72,6 @@ def _pop_or_get(resource, key, default, strict):
 
 
 class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
-
     @property
     def _compute_region(self):
         # This is only used in exception messages. Can we get rid of it?
@@ -381,12 +383,9 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
         """
         params = {}
         if name_or_id:
-            project = self.identity.find_project(name_or_id)
-            if not project:
-                raise exceptions.SDKException(
-                    f"Project {name_or_id} was requested but was not found "
-                    f"on the cloud"
-                )
+            project = self.identity.find_project(
+                name_or_id, ignore_missing=False
+            )
             params['tenant_id'] = project.id
         return self.compute.get_limits(**params).absolute
 
@@ -398,12 +397,7 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                'last_name': 'Smith',
-                'other': {
-                'gender': 'Female'
-                }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
             A string containing a jmespath expression for further filtering.
@@ -421,12 +415,7 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                    'last_name': 'Smith',
-                    'other': {
-                        'gender': 'Female'
-                    }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
             A string containing a jmespath expression for further filtering.
@@ -438,13 +427,12 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
         """
         if not filters:
             filters = {}
-        flavor = self.compute.find_flavor(
+        return self.compute.find_flavor(
             name_or_id,
             get_extra_specs=get_extra,
             ignore_missing=True,
             **filters,
         )
-        return flavor
 
     def get_flavor_by_id(self, id, get_extra=False):
         """Get a flavor by ID
@@ -505,12 +493,7 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
             A dictionary of meta data to use for further filtering. Elements
             of this dictionary may, themselves, be dictionaries. Example::
 
-                {
-                    'last_name': 'Smith',
-                    'other': {
-                        'gender': 'Female'
-                    }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
             A string containing a jmespath expression for further filtering.
@@ -843,15 +826,23 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
                 kwargs[desired] = value
 
         if group:
-            group_obj = self.compute.find_server_group(group)
-            if not group_obj:
-                raise exceptions.SDKException(
-                    "Server Group {group} was requested but was not found"
-                    " on the cloud".format(group=group)
+            if isinstance(group, dict):
+                if not isinstance(group, resource.Resource):
+                    warnings.warn(
+                        "Support for passing server group as a raw dict has "
+                        "been deprecated for removal. Consider passing a "
+                        "string name or ID or a ServerGroup object instead.",
+                        os_warnings.RemovedInSDK60Warning,
+                    )
+                group_id = group['id']
+            else:  # object
+                group_obj = self.compute.find_server_group(
+                    group, ignore_missing=False
                 )
+                group_id = group_obj['id']
             if 'scheduler_hints' not in kwargs:
                 kwargs['scheduler_hints'] = {}
-            kwargs['scheduler_hints']['group'] = group_obj['id']
+            kwargs['scheduler_hints']['group'] = group_id
 
         kwargs.setdefault('max_count', kwargs.get('max_count', 1))
         kwargs.setdefault('min_count', kwargs.get('min_count', 1))
@@ -870,21 +861,22 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
             nics = []
             if not isinstance(network, list):
                 network = [network]
-            for net_name in network:
-                if isinstance(net_name, dict) and 'id' in net_name:
-                    network_obj = net_name
-                else:
-                    network_obj = self.network.find_network(net_name)
-                if not network_obj:
-                    raise exceptions.SDKException(
-                        'Network {network} is not a valid network in'
-                        ' {cloud}:{region}'.format(
-                            network=network,
-                            cloud=self.name,
-                            region=self._compute_region,
+            for net in network:
+                if isinstance(net, dict):
+                    if not isinstance(net, resource.Resource):
+                        warnings.warn(
+                            "Support for passing network as a raw dict has "
+                            "been deprecated for removal. Consider passing a "
+                            "string name or ID or a Network object instead.",
+                            os_warnings.RemovedInSDK60Warning,
                         )
+                    network_id = net['id']
+                else:
+                    network_obj = self.network.find_network(
+                        net, ignore_missing=False
                     )
-                nics.append({'net-id': network_obj['id']})
+                    network_id = network_obj['id']
+                nics.append({'net-id': network_id})
 
             kwargs['nics'] = nics
         if not network and ('nics' not in kwargs or not kwargs['nics']):
@@ -902,13 +894,9 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
                 nic.pop('net-name', None)
             elif 'net-name' in nic:
                 net_name = nic.pop('net-name')
-                nic_net = self.network.find_network(net_name)
-                if not nic_net:
-                    raise exceptions.SDKException(
-                        "Requested network {net} could not be found.".format(
-                            net=net_name
-                        )
-                    )
+                nic_net = self.network.find_network(
+                    net_name, ignore_missing=False
+                )
                 net['uuid'] = nic_net['id']
             for ip_key in ('v4-fixed-ip', 'v6-fixed-ip', 'fixed_ip'):
                 fixed_ip = nic.pop(ip_key, None)
@@ -942,22 +930,27 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
                 kwargs['networks'] = 'auto'
 
         if image:
-            # TODO(stephenfin): Drop support for dicts: we should only accept
-            # strings or Image objects
             if isinstance(image, dict):
+                if not isinstance(image, resource.Resource):
+                    warnings.warn(
+                        "Support for passing image as a raw dict has "
+                        "been deprecated for removal. Consider passing a "
+                        "string name or ID or an Image object instead.",
+                        os_warnings.RemovedInSDK60Warning,
+                    )
                 kwargs['imageRef'] = image['id']
             else:
-                image_obj = self.image.find_image(image)
-                if not image_obj:
-                    raise exc.OpenStackCloudException(
-                        f"Image {image} was requested but was not found "
-                        f"on the cloud"
-                    )
+                image_obj = self.image.find_image(image, ignore_missing=False)
                 kwargs['imageRef'] = image_obj.id
 
-        # TODO(stephenfin): Drop support for dicts: we should only accept
-        # strings or Image objects
         if isinstance(flavor, dict):
+            if not isinstance(flavor, resource.Resource):
+                warnings.warn(
+                    "Support for passing flavor as a raw dict has "
+                    "been deprecated for removal. Consider passing a "
+                    "string name or ID or a Flavor object instead.",
+                    os_warnings.RemovedInSDK60Warning,
+                )
             kwargs['flavorRef'] = flavor['id']
         else:
             kwargs['flavorRef'] = self.get_flavor(flavor, get_extra=False).id
@@ -1048,33 +1041,41 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
         # If we have boot_from_volume but no root volume, then we're
         # booting an image from volume
         if boot_volume:
-            volume = self.block_storage.find_volume(boot_volume)
-            if not volume:
-                raise exceptions.SDKException(
-                    f"Volume {volume} was requested but was not found "
-                    f"on the cloud"
+            if isinstance(boot_volume, dict):
+                if not isinstance(boot_volume, resource.Resource):
+                    warnings.warn(
+                        "Support for passing boot_volume as a raw dict has "
+                        "been deprecated for removal. Consider passing a "
+                        "string name or ID or a Volume object instead.",
+                        os_warnings.RemovedInSDK60Warning,
+                    )
+                volume_id = boot_volume['id']
+            else:
+                volume = self.block_storage.find_volume(
+                    boot_volume, ignore_missing=False
                 )
+                volume_id = volume['id']
             block_mapping = {
                 'boot_index': '0',
                 'delete_on_termination': terminate_volume,
                 'destination_type': 'volume',
-                'uuid': volume['id'],
+                'uuid': volume_id,
                 'source_type': 'volume',
             }
             kwargs['block_device_mapping_v2'].append(block_mapping)
             kwargs['imageRef'] = ''
         elif boot_from_volume:
-            # TODO(stephenfin): Drop support for dicts: we should only accept
-            # strings or Image objects
             if isinstance(image, dict):
+                if not isinstance(image, resource.Resource):
+                    warnings.warn(
+                        "Support for passing image as a raw dict has "
+                        "been deprecated for removal. Consider passing a "
+                        "string name or ID or an Image object instead.",
+                        os_warnings.RemovedInSDK60Warning,
+                    )
                 image_obj = image
             else:
-                image_obj = self.image.find_image(image)
-                if not image_obj:
-                    raise exceptions.SDKException(
-                        f"Image {image} was requested but was not found "
-                        f"on the cloud"
-                    )
+                image_obj = self.image.find_image(image, ignore_missing=False)
 
             block_mapping = {
                 'boot_index': '0',
@@ -1086,6 +1087,7 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
             }
             kwargs['imageRef'] = ''
             kwargs['block_device_mapping_v2'].append(block_mapping)
+
         if volumes and kwargs['imageRef']:
             # If we're attaching volumes on boot but booting from an image,
             # we need to specify that in the BDM.
@@ -1097,18 +1099,27 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
                 'uuid': kwargs['imageRef'],
             }
             kwargs['block_device_mapping_v2'].append(block_mapping)
+
         for volume in volumes:
-            volume_obj = self.block_storage.find_volume(volume)
-            if not volume_obj:
-                raise exceptions.SDKException(
-                    f"Volume {volume} was requested but was not found "
-                    f"on the cloud"
+            if isinstance(volume, dict):
+                if not isinstance(volume, resource.Resource):
+                    warnings.warn(
+                        "Support for passing volumes as a list of raw dicts "
+                        "been deprecated for removal. Consider passing a list "
+                        "of string name or ID or ServerGroup objects instead.",
+                        os_warnings.RemovedInSDK60Warning,
+                    )
+                volume_id = volume['id']
+            else:
+                volume_obj = self.block_storage.find_volume(
+                    volume, ignore_missing=False
                 )
+                volume_id = volume_obj['id']
             block_mapping = {
                 'boot_index': '-1',
                 'delete_on_termination': False,
                 'destination_type': 'volume',
-                'uuid': volume_obj['id'],
+                'uuid': volume_id,
                 'source_type': 'volume',
             }
             kwargs['block_device_mapping_v2'].append(block_mapping)
@@ -1426,7 +1437,6 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
             error.
         """
         server = self.compute.find_server(name_or_id, ignore_missing=False)
-
         server = self.compute.update_server(server, **kwargs)
 
         return self._expand_server(server, bare=bare, detailed=detailed)
@@ -1524,7 +1534,7 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
             error.
         """
         try:
-            flavor = self.compute.find_flavor(name_or_id)
+            flavor = self.compute.find_flavor(name_or_id, ignore_missing=True)
             if not flavor:
                 self.log.debug("Flavor %s not found for deleting", name_or_id)
                 return False
@@ -1640,9 +1650,7 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
 
                 {
                     'availability_zone': 'nova',
-                    'metadata': {
-                        'cpu_allocation_ratio': '1.0'
-                    }
+                    'metadata': {'cpu_allocation_ratio': '1.0'},
                 }
 
         :returns: An aggregate dict or None if no matching aggregate is
@@ -1825,14 +1833,9 @@ class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
         if isinstance(end, str):
             end = parse_date(end)
 
-        proj = self.identity.find_project(name_or_id)
-        if not proj:
-            raise exceptions.SDKException(
-                f"Project {name_or_id} was requested but was not found "
-                f"on the cloud"
-            )
+        project = self.identity.find_project(name_or_id, ignore_missing=False)
 
-        return self.compute.get_usage(proj, start, end)
+        return self.compute.get_usage(project, start, end)
 
     def _encode_server_userdata(self, userdata):
         if hasattr(userdata, 'read'):
