@@ -20,7 +20,6 @@ from openstack import warnings as os_warnings
 
 
 class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
-
     def _get_project_id_param_dict(self, name_or_id):
         if name_or_id:
             project = self.get_project(name_or_id)
@@ -73,12 +72,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -114,12 +108,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -141,12 +130,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -181,9 +165,8 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
         project = self.identity.find_project(
             name_or_id=name_or_id,
             domain_id=domain_id,
+            ignore_missing=False,
         )
-        if not project:
-            raise exceptions.SDKException("Project %s not found." % name_or_id)
         if enabled is not None:
             kwargs.update({'enabled': enabled})
         project = self.identity.update_project(project, **kwargs)
@@ -227,7 +210,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
         """
         try:
             project = self.identity.find_project(
-                name_or_id=name_or_id, ignore_missing=True, domain_id=domain_id
+                name_or_id=name_or_id, domain_id=domain_id, ignore_missing=True
             )
             if not project:
                 self.log.debug("Project %s not found for deleting", name_or_id)
@@ -264,12 +247,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -304,12 +282,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -325,12 +298,19 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
         return _utils._get_entity(self, 'user', name_or_id, filters, **kwargs)
 
     # TODO(stephenfin): Remove normalize since it doesn't do anything
-    def get_user_by_id(self, user_id, normalize=True):
+    def get_user_by_id(self, user_id, normalize=None):
         """Get a user by ID.
 
         :param string user_id: user ID
         :returns: an identity ``User`` object
         """
+        if normalize is not None:
+            warnings.warn(
+                "The 'normalize' field is unnecessary and will be removed in "
+                "a future release.",
+                os_warnings.RemovedInSDK60Warning,
+            )
+
         return self.identity.get_user(user_id)
 
     @_utils.valid_kwargs(
@@ -506,12 +486,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -675,12 +650,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -837,12 +807,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -875,12 +840,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             further filtering. Elements of this dictionary may, themselves, be
             dictionaries. Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -894,7 +854,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             wrong during the OpenStack API call.
         """
         if domain_id is None:
-            return self.identity.find_domain(name_or_id)
+            return self.identity.find_domain(name_or_id, ignore_missing=True)
         else:
             return self.identity.get_domain(domain_id)
 
@@ -919,12 +879,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -999,11 +954,9 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
         :raises: :class:`~openstack.exceptions.SDKException` if something goes
             wrong during the OpenStack API call.
         """
-        group = self.identity.find_group(name_or_id, **kwargs)
-        if group is None:
-            raise exceptions.SDKException(
-                f"Group {name_or_id} not found for updating"
-            )
+        group = self.identity.find_group(
+            name_or_id, ignore_missing=False, **kwargs
+        )
 
         group_ref = {}
         if name:
@@ -1025,7 +978,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             wrong during the OpenStack API call.
         """
         try:
-            group = self.identity.find_group(name_or_id)
+            group = self.identity.find_group(name_or_id, ignore_missing=True)
             if group is None:
                 self.log.debug("Group %s not found for deleting", name_or_id)
                 return False
@@ -1055,12 +1008,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             Elements of this dictionary may, themselves, be dictionaries.
             Example::
 
-                {
-                  'last_name': 'Smith',
-                  'other': {
-                      'gender': 'Female'
-                  }
-                }
+                {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
             OR
 
@@ -1120,7 +1068,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             warnings.warn(
                 "os_inherit_extension_inherited_to is deprecated. Use "
                 "inherited_to instead.",
-                os_warnings.OpenStackDeprecationWarning,
+                os_warnings.RemovedInSDK50Warning,
             )
             filters['scope.OS-INHERIT:inherited_to'] = filters[
                 'os_inherit_extension_inherited_to'
@@ -1190,7 +1138,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             warnings.warn(
                 "os_inherit_extension_inherited_to is deprecated. Use "
                 "inherited_to instead.",
-                os_warnings.OpenStackDeprecationWarning,
+                os_warnings.RemovedInSDK50Warning,
             )
             filters['inherited_to'] = filters.pop(
                 'os_inherit_extension_inherited_to'
@@ -1271,9 +1219,7 @@ class IdentityCloudMixin(openstackcloud._OpenStackCloudMixin):
             # group, role, project
             search_args['domain_id'] = data['domain'].id
 
-        data['role'] = self.identity.find_role(name_or_id=role)
-        if not data['role']:
-            raise exceptions.SDKException(f'Role {role} not found.')
+        data['role'] = self.identity.find_role(role, ignore_missing=False)
 
         if user:
             # use cloud.get_user to save us from bad searching by name
