@@ -210,15 +210,19 @@ class OpenStackConfig:
 
         # First, use a config file if it exists where expected
         self.config_filename, self.cloud_config = self._load_config_file()
-        _, secure_config = self._load_secure_file()
+        if self.config_filename:
+            self._validate_config_file(self.config_filename, self.cloud_config)
+
+        secure_config_filename, secure_config = self._load_secure_file()
         if secure_config:
+            self._validate_config_file(secure_config_filename, secure_config)
             self.cloud_config = _util.merge_clouds(
                 self.cloud_config, secure_config
             )
 
         if not self.cloud_config:
             self.cloud_config = {'clouds': {}}
-        if 'clouds' not in self.cloud_config:
+        elif 'clouds' not in self.cloud_config:
             self.cloud_config['clouds'] = {}
 
         # Save the other config
@@ -466,6 +470,25 @@ class OpenStackConfig:
                         continue
         return (None, {})
 
+    def _validate_config_file(self, path: str, data: ty.Any) -> bool:
+        """Validate config file contains a clouds entry.
+
+        All config files should have a 'clouds' key at a minimum.
+        """
+        if not isinstance(data, dict):
+            raise exceptions.ConfigException(
+                'Configuration file {path} is empty or not a valid mapping'
+            )
+
+        if 'clouds' not in data:
+            # TODO(stephenfin): This should probably be an error at some point
+            self.log.warning(
+                "Configuration file %s does not contain a 'clouds' key", path
+            )
+            return False
+
+        return True
+
     def _expand_region_name(self, region_name):
         return {'name': region_name, 'values': {}}
 
@@ -961,8 +984,13 @@ class OpenStackConfig:
                     )
         return clouds
 
-    # TODO(mordred) Backwards compat for OSC transition
-    get_all_clouds = get_all
+    def get_all_clouds(self):
+        warnings.warn(
+            "The 'get_all_clouds' method is a deprecated alias for "
+            "'get_clouds' and will be removed in a future release.",
+            os_warnings.RemovedInSDK60Warning,
+        )
+        return self.get_all()
 
     def _fix_args(self, args=None, argparse=None):
         """Massage the passed-in options
@@ -1320,8 +1348,20 @@ class OpenStackConfig:
             influxdb_config=influxdb_config,
         )
 
-    # TODO(mordred) Backwards compat for OSC transition
-    get_one_cloud = get_one
+    def get_one_cloud(
+        self, cloud=None, validate=True, argparse=None, **kwargs
+    ):
+        warnings.warn(
+            "The 'get_one_cloud' method is a deprecated alias for 'get_one' "
+            "and will be removed in a future release.",
+            os_warnings.RemovedInSDK60Warning,
+        )
+        return self.get_one(
+            cloud=cloud,
+            validate=validate,
+            argparse=argparse,
+            **kwargs,
+        )
 
     def get_one_cloud_osc(
         self, cloud=None, validate=True, argparse=None, **kwargs
