@@ -349,9 +349,9 @@ class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
 
         if remote_region and remote_image_id:
             if remote_service_interface:
-                data['method'][
-                    'glance_service_interface'
-                ] = remote_service_interface
+                data['method']['glance_service_interface'] = (
+                    remote_service_interface
+                )
                 data['method']['glance_region'] = remote_region
                 data['method']['glance_image_id'] = remote_image_id
 
@@ -383,6 +383,7 @@ class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
         prepend_key=False,
         patch=False,
         base_path=None,
+        params=None,
         **kwargs,
     ):
         request = super()._prepare_request(
@@ -390,6 +391,8 @@ class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
             prepend_key=prepend_key,
             patch=patch,
             base_path=base_path,
+            params=params,
+            **kwargs,
         )
         if patch:
             headers = {
