@@ -52,7 +52,7 @@ class Proxy(proxy.Proxy):
         if (
             url_parts[0] == 'stacks'
             and len(url_parts) > 2
-            and not url_parts[2] in ['preview', 'resources']
+            and url_parts[2] not in ['preview', 'resources']
         ):
             # orchestrate introduce having stack name and id part of the URL
             # (/stacks/name/id/everything_else), so if on third position we
@@ -167,7 +167,7 @@ class Proxy(proxy.Proxy):
         """
         return self._get(_stack.Stack, stack, resolve_outputs=resolve_outputs)
 
-    def update_stack(self, stack, preview=False, **attrs):
+    def update_stack(self, stack, *, preview=False, **attrs):
         """Update a stack
 
         :param stack: The value can be the ID of a stack or a
@@ -181,7 +181,7 @@ class Proxy(proxy.Proxy):
             when no resource can be found.
         """
         res = self._get_resource(_stack.Stack, stack, **attrs)
-        return res.update(self, preview)
+        return res.commit(self, preview)
 
     def delete_stack(self, stack, ignore_missing=True):
         """Delete a stack
@@ -635,12 +635,12 @@ class Proxy(proxy.Proxy):
                 stack_id=obj.id,
                 resource_name=resource_name,
                 base_path=base_path,
-                **attr
+                **attr,
             )
 
         return self._list(
             _stack_event.StackEvent,
             stack_name=obj.name,
             stack_id=obj.id,
-            **attr
+            **attr,
         )
