@@ -83,6 +83,7 @@ FAKE = {
     "service_step": {},
     "secure_boot": True,
     "shard": "TestShard",
+    "runbook": None,
     "states": [
         {
             "href": "http://127.0.0.1:6385/v1/nodes/<NODE_ID>/states",
@@ -161,6 +162,7 @@ class TestNode(base.TestCase):
         self.assertEqual(FAKE['resource_class'], sot.resource_class)
         self.assertEqual(FAKE['service_step'], sot.service_step)
         self.assertEqual(FAKE['secure_boot'], sot.is_secure_boot)
+        self.assertEqual(FAKE['runbook'], sot.runbook)
         self.assertEqual(FAKE['states'], sot.states)
         self.assertEqual(
             FAKE['target_provision_state'], sot.target_provision_state
@@ -438,6 +440,36 @@ class TestNodeSetProvisionState(base.TestCase):
             retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
         )
 
+    def test_set_provision_state_clean_runbook(self):
+        runbook = 'CUSTOM_AWESOME'
+        result = self.node.set_provision_state(
+            self.session, 'clean', runbook=runbook
+        )
+
+        self.assertIs(result, self.node)
+        self.session.put.assert_called_once_with(
+            'nodes/%s/states/provision' % self.node.id,
+            json={'target': 'clean', 'runbook': runbook},
+            headers=mock.ANY,
+            microversion='1.92',
+            retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
+        )
+
+    def test_set_provision_state_service_runbook(self):
+        runbook = 'CUSTOM_AWESOME'
+        result = self.node.set_provision_state(
+            self.session, 'service', runbook=runbook
+        )
+
+        self.assertIs(result, self.node)
+        self.session.put.assert_called_once_with(
+            'nodes/%s/states/provision' % self.node.id,
+            json={'target': 'service', 'runbook': runbook},
+            headers=mock.ANY,
+            microversion='1.92',
+            retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
+        )
+
 
 @mock.patch.object(node.Node, '_translate_response', mock.Mock())
 @mock.patch.object(node.Node, '_get_session', lambda self, x: x)
@@ -558,12 +590,14 @@ class TestNodeVif(base.TestCase):
     def setUp(self):
         super().setUp()
         self.session = mock.Mock(spec=adapter.Adapter)
-        self.session.default_microversion = '1.28'
+        self.session.default_microversion = '1.67'
         self.session.log = mock.Mock()
         self.node = node.Node(
             id='c29db401-b6a7-4530-af8e-20a720dee946', driver=FAKE['driver']
         )
         self.vif_id = '714bdf6d-2386-4b5e-bd0d-bc036f04b1ef'
+        self.vif_port_uuid = 'port-uuid'
+        self.vif_portgroup_uuid = 'portgroup-uuid'
 
     def test_attach_vif(self):
         self.assertIsNone(self.node.attach_vif(self.session, self.vif_id))
@@ -571,7 +605,7 @@ class TestNodeVif(base.TestCase):
             'nodes/%s/vifs' % self.node.id,
             json={'id': self.vif_id},
             headers=mock.ANY,
-            microversion='1.28',
+            microversion='1.67',
             retriable_status_codes=[409, 503],
         )
 
@@ -585,16 +619,59 @@ class TestNodeVif(base.TestCase):
             'nodes/%s/vifs' % self.node.id,
             json={'id': self.vif_id},
             headers=mock.ANY,
-            microversion='1.28',
+            microversion='1.67',
             retriable_status_codes=[503],
         )
 
+    def test_attach_vif_with_port_uuid(self):
+        self.assertIsNone(
+            self.node.attach_vif(
+                self.session, self.vif_id, port_id=self.vif_port_uuid
+            )
+        )
+        self.session.post.assert_called_once_with(
+            'nodes/%s/vifs' % self.node.id,
+            json={'id': self.vif_id, 'port_uuid': self.vif_port_uuid},
+            headers=mock.ANY,
+            microversion='1.67',
+            retriable_status_codes=[409, 503],
+        )
+
+    def test_attach_vif_with_portgroup_uuid(self):
+        self.assertIsNone(
+            self.node.attach_vif(
+                self.session,
+                self.vif_id,
+                port_group_id=self.vif_portgroup_uuid,
+            )
+        )
+        self.session.post.assert_called_once_with(
+            'nodes/%s/vifs' % self.node.id,
+            json={
+                'id': self.vif_id,
+                'portgroup_uuid': self.vif_portgroup_uuid,
+            },
+            headers=mock.ANY,
+            microversion='1.67',
+            retriable_status_codes=[409, 503],
+        )
+
+    def test_attach_vif_with_port_uuid_and_portgroup_uuid(self):
+        self.assertRaises(
+            exceptions.InvalidRequest,
+            self.node.attach_vif,
+            self.session,
+            self.vif_id,
+            port_id=self.vif_port_uuid,
+            port_group_id=self.vif_portgroup_uuid,
+        )
+
     def test_detach_vif_existing(self):
         self.assertTrue(self.node.detach_vif(self.session, self.vif_id))
         self.session.delete.assert_called_once_with(
             f'nodes/{self.node.id}/vifs/{self.vif_id}',
             headers=mock.ANY,
-            microversion='1.28',
+            microversion='1.67',
             retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
         )
 
@@ -604,7 +681,7 @@ class TestNodeVif(base.TestCase):
         self.session.delete.assert_called_once_with(
             f'nodes/{self.node.id}/vifs/{self.vif_id}',
             headers=mock.ANY,
-            microversion='1.28',
+            microversion='1.67',
             retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
         )
 
@@ -620,7 +697,7 @@ class TestNodeVif(base.TestCase):
         self.session.get.assert_called_once_with(
             'nodes/%s/vifs' % self.node.id,
             headers=mock.ANY,
-            microversion='1.28',
+            microversion='1.67',
         )
 
     def test_incompatible_microversion(self):
@@ -641,6 +718,23 @@ class TestNodeVif(base.TestCase):
             exceptions.NotSupported, self.node.list_vifs, self.session
         )
 
+    def test_incompatible_microversion_optional_params(self):
+        self.session.default_microversion = '1.28'
+        self.assertRaises(
+            exceptions.NotSupported,
+            self.node.attach_vif,
+            self.session,
+            self.vif_id,
+            port_id=self.vif_port_uuid,
+        )
+        self.assertRaises(
+            exceptions.NotSupported,
+            self.node.attach_vif,
+            self.session,
+            self.vif_id,
+            port_group_id=self.vif_portgroup_uuid,
+        )
+
 
 @mock.patch.object(exceptions, 'raise_from_response', mock.Mock())
 @mock.patch.object(node.Node, '_get_session', lambda self, x: x)
