@@ -10,6 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import hashlib
 import io
 import operator
 import tempfile
@@ -22,7 +23,6 @@ from openstack import _log
 from openstack import exceptions
 from openstack.image.v2 import image
 from openstack.tests.unit import base
-from openstack import utils
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -93,7 +93,7 @@ EXAMPLE = {
 
 
 def calculate_md5_checksum(data):
-    checksum = utils.md5(usedforsecurity=False)
+    checksum = hashlib.md5(usedforsecurity=False)
     for chunk in data:
         checksum.update(chunk)
     return checksum.hexdigest()
